@@ -1,10 +1,7 @@
-source_files <- list.files("./old_function/", "*.R$")
-sapply(paste0("./old_function/", source_files), source)
-
 test_that("Call with defaults", {
   x1 <- gs_design_ahr()
   x2 <- gs_design_ahr_()
-  expect_equal(x1$analysis$time, x2$bounds$Time[x2$bounds$Bound == "Upper"])
+  expect_equivalent(x1$analysis$time, x2$bounds$Time[x2$bounds$Bound == "Upper"])
   expect_equal(x1$analysis$event, x2$bounds$Events[x2$bounds$Bound == "Upper"])
   expect_equal(x1$bound$z[x1$bound$bound == "upper"], x2$bounds$Z[x2$bounds$Bound == "Upper"])
   expect_equal(x1$bound$probability[x1$bound$bound == "upper"], x2$bounds$Probability[x2$bounds$Bound == "Upper"])
@@ -45,14 +42,14 @@ test_that("Multiple analysisTimes", {
 test_that("Specified information fraction", {
   x1 <- gs_design_ahr(info_frac = c(.25, .75, 1), analysis_time = 36)
   x2 <- gs_design_ahr_(IF = c(.25, .75, 1), analysisTimes = 36)
-  expect_equal(x1$analysis$time, x2$bounds$Time[x2$bounds$Bound == "Upper"])
-  expect_equal(x1$analysis$event, x2$bounds$Events[x2$bounds$Bound == "Upper"])
+  expect_equal(x1$analysis$time, x2$bounds$Time[x2$bounds$Bound == "Upper"], tol = 1e-6)
+  expect_equal(x1$analysis$event, x2$bounds$Events[x2$bounds$Bound == "Upper"], tol = 1e-6)
   expect_equal(x1$bound$z[x1$bound$bound == "upper"], x2$bounds$Z[x2$bounds$Bound == "Upper"])
   expect_equal(x1$bound$probability[x1$bound$bound == "upper"], x2$bounds$Probability[x2$bounds$Bound == "Upper"])
   expect_equal(x1$analysis$ahr, x2$bounds$AHR[x2$bounds$Bound == "Upper"])
-  expect_equal(x1$analysis$theta, x2$bounds$theta[x2$bounds$Bound == "Upper"])
-  expect_equal(x1$analysis$info, x2$bounds$info[x2$bounds$Bound == "Upper"])
-  expect_equal(x1$analysis$info0, x2$bounds$info0[x2$bounds$Bound == "Upper"])
+  expect_equal(x1$analysis$theta, x2$bounds$theta[x2$bounds$Bound == "Upper"], tol = 1e-6)
+  expect_equal(x1$analysis$info, x2$bounds$info[x2$bounds$Bound == "Upper"], tol = 1e-6)
+  expect_equal(x1$analysis$info0, x2$bounds$info0[x2$bounds$Bound == "Upper"], tol = 1e-6)
   expect_equal(x1$bound$z[x1$bound$bound == "lower"], x2$bounds$Z[x2$bounds$Bound == "Lower"][1])
   expect_equal(x1$bound$probability[x1$bound$bound == "lower"], x2$bounds$Probability[x2$bounds$Bound == "Lower"][1])
 })
