@@ -1,30 +1,5 @@
-test_eAccrual <- function(x, enroll_rate) {
-  boundary <- cumsum(enroll_rate$duration)
-  rate <- enroll_rate$rate
-  xvals <- unique(c(x, boundary))
-
-  eAc2 <- numeric(length(xvals))
-  for (t in seq_along(xvals)) {
-    val <- xvals[t]
-    if (val <= boundary[1]) {
-      eAc2[t] <- val * rate[1]
-    } else if (val <= boundary[2]) {
-      eAc2[t] <- boundary[1] * rate[1] + (val - boundary[1]) * rate[2]
-    } else if (val <= boundary[3]) {
-      eAc2[t] <- boundary[1] * rate[1] +
-        (boundary[2] - boundary[1]) * rate[2] + (val - boundary[2]) * rate[3]
-    } else {
-      eAc2[t] <- boundary[1] * rate[1] +
-        (boundary[2] - boundary[1]) * rate[2] + (boundary[3] - boundary[2]) * rate[3]
-    }
-  }
-
-  ind <- !is.na(match(xvals, x))
-  return(eAc2[ind])
-}
-
-testthat::test_that("expect_accrua doesn't match with the double programming e_Acurral function", {
-  testthat::expect_equal(
+test_that("expected_accrual doesn't match with the double programming test_eAccrual function", {
+  expect_equal(
     expected_accrual(
       time = 0:30,
       enroll_rate = define_enroll_rate(
@@ -42,7 +17,7 @@ testthat::test_that("expect_accrua doesn't match with the double programming e_A
   )
 })
 
-testthat::test_that("expect_accrual fail to identify a non-numerical input", {
+test_that("expected_accrual fail to identify a non-numerical input", {
   x <- c(0:20, "NA")
   expect_error(expect_message(
     expected_accrual(time = x),
@@ -50,7 +25,7 @@ testthat::test_that("expect_accrual fail to identify a non-numerical input", {
   ))
 })
 
-testthat::test_that("expect_accrual fail to identify a negative input", {
+test_that("expected_accrual fail to identify a negative input", {
   x <- -20:-1
   expect_error(expect_message(
     expected_accrual(time = x),
@@ -58,7 +33,7 @@ testthat::test_that("expect_accrual fail to identify a negative input", {
   ))
 })
 
-testthat::test_that("expect_accrual fail to identify a non-increasing input", {
+test_that("expected_accrual fail to identify a non-increasing input", {
   x <- 20:1
   expect_error(expect_message(
     expected_accrual(time = x),
@@ -67,7 +42,7 @@ testthat::test_that("expect_accrual fail to identify a non-increasing input", {
 })
 
 # Add test cases for stratified design
-testthat::test_that("expect_accrua fail to identify a non-dataframe input", {
+test_that("expected_accrual fail to identify a non-dataframe input", {
   x <- expected_accrual(
     time = 40,
     enroll_rate = define_enroll_rate(
@@ -79,7 +54,7 @@ testthat::test_that("expect_accrua fail to identify a non-dataframe input", {
   expect_equal(x, 33 * 30 * 2)
 })
 
-testthat::test_that("expect_accrua fail to identify a non-dataframe input", {
+test_that("expected_accrual fail to identify a non-dataframe input", {
   x <- expected_accrual(
     time = 33,
     enroll_rate = define_enroll_rate(
@@ -91,7 +66,7 @@ testthat::test_that("expect_accrua fail to identify a non-dataframe input", {
   expect_equal(x, 33 * 30 * 2)
 })
 
-testthat::test_that("expect_accrua fail to identify a non-dataframe input", {
+test_that("expected_accrual fail to identify a non-dataframe input", {
   x <- expected_accrual(
     time = 30,
     enroll_rate = define_enroll_rate(
@@ -103,7 +78,7 @@ testthat::test_that("expect_accrua fail to identify a non-dataframe input", {
   expect_equal(x, 30 * 30 * 2)
 })
 
-testthat::test_that("expect_accrua fail to identify a non-dataframe input", {
+test_that("expected_accrual fail to identify a non-dataframe input", {
   x <- expected_accrual(
     time = 10,
     enroll_rate = define_enroll_rate(
@@ -115,7 +90,7 @@ testthat::test_that("expect_accrua fail to identify a non-dataframe input", {
   expect_equal(x, 10 * 30 * 2)
 })
 
-testthat::test_that("expect_accrual fail to identify a non-dataframe input", {
+test_that("expected_accrual fail to identify a non-dataframe input", {
   x <- expected_accrual(
     time = c(5, 10, 20, 33, 50),
     enroll_rate = define_enroll_rate(
